==> qtmultimedia-opensource-src_5.12.8.orig.tar.xz: qtmultimedia-everywhere-src-5.12.8/src/plugins/directshow/player/directshowaudioendpointcontrol.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DIRECTSHOWAUDIOENDPOINTCONTROL_H
#define DIRECTSHOWAUDIOENDPOINTCONTROL_H

#include "qaudiooutputselectorcontrol.h"

#include <dshow.h>

QT_BEGIN_NAMESPACE

class DirectShowPlayerService;

class DirectShowAudioEndpointControl : public QAudioOutputSelectorControl
{
    Q_OBJECT
public:
    DirectShowAudioEndpointControl(DirectShowPlayerService *service, QObject *parent = 0);
    ~DirectShowAudioEndpointControl() override;

    QList<QString> availableOutputs() const override;

    QString outputDescription(const QString &name) const override;

    QString defaultOutput() const override;
    QString activeOutput() const override;

    void setActiveOutput(const QString& name) override;

private:
    void updateEndpoints();

    DirectShowPlayerService *m_service;
    IBindCtx *m_bindContext;
    ICreateDevEnum *m_deviceEnumerator;

    QMap<QString, IMoniker *> m_devices;
    QString m_defaultEndpoint;
    QString m_activeEndpoint;
};

QT_END_NAMESPACE

#endif

==> qtmultimedia-opensource-src_5.15.15.orig.tar.xz: qtmultimedia-everywhere-src-5.15.15/src/plugins/directshow/player/directshowaudioendpointcontrol.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DIRECTSHOWAUDIOENDPOINTCONTROL_H
#define DIRECTSHOWAUDIOENDPOINTCONTROL_H

#include "qaudiooutputselectorcontrol.h"

#include <dshow.h>

QT_BEGIN_NAMESPACE

class DirectShowPlayerService;

class DirectShowAudioEndpointControl : public QAudioOutputSelectorControl
{
    Q_OBJECT
public:
    DirectShowAudioEndpointControl(DirectShowPlayerService *service, QObject *parent = nullptr);
    ~DirectShowAudioEndpointControl() override;

    QList<QString> availableOutputs() const override;

    QString outputDescription(const QString &name) const override;

    QString defaultOutput() const override;
    QString activeOutput() const override;

    void setActiveOutput(const QString& name) override;

private:
    void updateEndpoints();

    DirectShowPlayerService *m_service;
    IBindCtx *m_bindContext = nullptr;
    ICreateDevEnum *m_deviceEnumerator = nullptr;

    QMap<QString, IMoniker *> m_devices;
    QString m_defaultEndpoint;
    QString m_activeEndpoint;
};

QT_END_NAMESPACE

#endif
